@@ -1,3 +1,3 @@
 utils::globalVariables(c("CH", "Classification", "DB",
                          "Evaluation", "Metrics", "Sample",
-                         "average_Silhouette", "k", "median_Silhouette"))
+                         "average_Silhouette", "k", "median_Silhouette", "maxk"))
